﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections;
using Syncfusion.Windows.Controls.Grid;
using Syncfusion.Grouping;
using Syncfusion.Windows.Styles;
using Syncfusion.Windows.Controls.Scroll;


namespace GroupingSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {

        private GroupingHelper groupingHelper;
        public Window1()
        {
             InitializeComponent();

           //get a datasource
            int count = 50000;
             IEnumerable list = SampleData.GenerateSampleData(count);

             DateTime start = DateTime.Now;
           
            //enable grouping support of the grid holding the datasource
             groupingHelper = new GroupingHelper(grid, list);

            //align all the cells right by default
             grid.Model.TableStyle.HorizontalAlignment = HorizontalAlignment.Right;

            //align the Name column to the left by setting its ColumnStyleInfo
             groupingHelper.ColumnStyles["Name"].Style.HorizontalAlignment = HorizontalAlignment.Left;

           //set the Headertext to something other than the column name
            groupingHelper.ColumnStyles["Col2"].HeaderText = "Column 2";

            //specify column order
            groupingHelper.VisibleColumns.Clear();
            groupingHelper.VisibleColumns.AddRange(new string[] { "Name", "Col4", "Col0", "Col1", "Col2", "Col3", "Col5", "Col6", "Col7", "Col8"});
            groupingHelper.ResetDisplay();

            ////only a few columns...
            //groupingHelper.VisibleColumns.Clear();
            //groupingHelper.VisibleColumns.AddRange(new string[] { "Name", "Col2", "Col3" });
            //groupingHelper.ResetDisplay();


            //set up some colors...
            //not needed here...
           //////////enable recordcellspanbackgrounds
           //////// groupingHelper.RecordSpanInfoBrush = new LinearGradientBrush(Colors.AliceBlue, Colors.LightBlue, 45);

           //////// //enable spacerSpansBackgrounds
           //////// groupingHelper.SpacerSpanInfoBrush = new LinearGradientBrush(Colors.AliceBlue, Colors.LightBlue, 45); //new LinearGradientBrush(Colors.LightBlue, Colors.AliceBlue, 90);

           //////// //set caption background
           //////// groupingHelper.CellStyleForCaption.Background = new LinearGradientBrush(Colors.LightBlue, Colors.AliceBlue, 45);

           //////// //set expand cell background
           //////// groupingHelper.CellStyleForExpand.Background = new LinearGradientBrush(Colors.AliceBlue, Colors.LightBlue, 45);

            //set summary cell background
            groupingHelper.CellStyleForSummary.Background = Brushes.AliceBlue;
            groupingHelper.CellStyleForSummary.HorizontalAlignment = HorizontalAlignment.Right;
            groupingHelper.CellStyleForSummarySpacer.Background = Brushes.AliceBlue;
            groupingHelper.CellStyleForSummaryRowHeader.Background = Brushes.AliceBlue;
            groupingHelper.CellStyleForSummaryRowHeader.Borders.Right = null; //no border


            Brush b = new SolidColorBrush(Color.FromArgb(50, Colors.DodgerBlue.R, Colors.DodgerBlue.G, Colors.DodgerBlue.B));

            //columnheaders
            groupingHelper.CellStyleForColumnHeader.Background = b;
            groupingHelper.CellStyleForColumnHeaderRowHeader.Background = b;

            //rowheaders
            groupingHelper.CellStyleForRecordRowHeader.Background = b;
            groupingHelper.CellStyleForLastRecordRowHeader.Background = b;
            
            //addnew rowheader
            groupingHelper.CellStyleForAddNewRowHeader.Background = b;

            //caption rowheader
            groupingHelper.CellStyleForCaptionRowHeader.Background = b;

           //add some summaries
            SummaryDescriptor sd = new SummaryDescriptor("Col2", SummaryType.Int32Aggregate);
            groupingHelper.SetSummary("Col2", sd, false, "Sum"); //false indicates to hold off resetting the display
            sd = new SummaryDescriptor("Col1", SummaryType.Int32Aggregate);
            groupingHelper.SetSummary("Col1", sd, false, "Maximum");
            sd = new SummaryDescriptor("Name", SummaryType.Count);
            groupingHelper.SetSummary("Name", sd, false, "Count");
            sd = new SummaryDescriptor("Col0", SummaryType.Int32Aggregate);
            groupingHelper.SetSummary("Col0", sd, true, "Minimum"); //true indicates to reset the display

            //show summary row
            groupingHelper.ShowSummary = true;
            
            //group by Col3
           // groupingHelper.ToggleGroupColumn("Col3");
            groupingHelper.ExpandAllGroups();

            //set footer count so summary row is fixed
            grid.Model.FooterRows = 1;

            //hide the toplevel group
            grid.Model.RowHeights[1] = 0;

            //hide the expand column
            grid.Model.ColumnWidths[1] = 0;

            //set gridline color
            grid.Model.TableStyle.Borders.Right = new Pen(Brushes.Red, .5);
            grid.Model.TableStyle.Borders.Bottom = new Pen(Brushes.Red, .5);

            //set listbox selection mode...
            grid.Model.Options.ListBoxSelectionMode = GridSelectionMode.One;
            grid.Model.Options.ShowCurrentCell = false;

            //to color selected row
            //set the hightlight color
            grid.HighlightBrush = new SolidColorBrush(Color.FromArgb((byte)60, Colors.Pink.R, Colors.Pink.G, Colors.Pink.B));
            //use event to control font
            grid.PrepareRenderCell += new GridPrepareRenderCellEventHandler(grid_PrepareRenderCell);
            //use event to force refresh
            grid.Model.SelectionChanged += new GridSelectionChangedEventHandler(Model_SelectionChanged);

            //static cells
            grid.Model.TableStyle.CellType = "Static";

            //use this event to make sure grid fills client area
            grid.Model.ColumnWidths.LineSizeChanged += new RangeChangedEventHandler(ColumnWidths_LineSizeChanged);
            this.SizeChanged += new SizeChangedEventHandler(Window1_SizeChanged);

            SetRightColumnToFillGrid();

            this.Title = string.Format("{0} records in {1} secs.", count, DateTime.Now.Subtract(start).TotalSeconds);
         }

        void ColumnWidths_LineSizeChanged(object sender, Syncfusion.Windows.Controls.Scroll.RangeChangedEventArgs e)
        {
            if (!inFillLastColumn)
            {
                SetRightColumnToFillGrid();
            }
        }

        void Window1_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            SetRightColumnToFillGrid();
        }

        bool inFillLastColumn = false;
        double border = 8;
        double scrollBarWidth = 17;
        private void SetRightColumnToFillGrid()
        {
            inFillLastColumn = true;
            double w = 0;
            for (int col = 0; col < grid.Model.ColumnCount - 1; ++col)
                w += grid.Model.ColumnWidths[col];
            if (w < this.Width)
            {
                double targetWidth = this.Width - 2 * border - 1;
                targetWidth -= ((grid.TopRowIndex != 1 || !grid.IsRowVisible(grid.Model.RowCount - 1)) ? scrollBarWidth : 0d);
                grid.Model.ColumnWidths[grid.Model.ColumnCount - 1] = targetWidth - w;
                grid.InvalidateCells();
            }
            inFillLastColumn = false;
        }

       
        

        void Model_SelectionChanged(object sender, GridSelectionChangedEventArgs e)
        {
            GridModel model = sender as GridModel;
            model.Views.First().InvalidateCells();
        }

        void grid_PrepareRenderCell(object sender, GridPrepareRenderCellEventArgs e)
        {
            GridControl grid  = sender as GridControl;
            if (grid.Model.SelectedCells.IntersectsWith(GridRangeInfo.Cell(e.Cell.RowIndex, e.Cell.ColumnIndex)))
            {
                e.Style.Font.FontWeight = FontWeights.Bold;
            }
        }
    }
}
